@@ -261,7 +261,7 @@ class ArrowMathTests(Chai):
 
     def test_add_other(self):
 
-        with assertRaises(NotImplementedError):
+        with assertRaises(TypeError):
             self.arrow.__add__(1)
 
     def test_radd(self):
@@ -290,7 +290,7 @@ class ArrowMathTests(Chai):
 
     def test_sub_other(self):
 
-        with assertRaises(NotImplementedError):
+        with assertRaises(TypeError):
             self.arrow.__sub__(object())
 
     def test_rsub(self):
@@ -569,6 +569,13 @@ class ArrowRangeTests(Chai):
             arrow.Arrow(2013, 1, 2, 6, 4, 5),
         ])
 
+        result = arrow.Arrow.range('hour', datetime(2013, 1, 2, 3, 4, 5),
+            datetime(2013, 1, 2, 3, 4, 5))
+
+        assertEqual(result, [
+            arrow.Arrow(2013, 1, 2, 3, 4, 5),
+        ])
+
     def test_minute(self):
 
         result = arrow.Arrow.range('minute', datetime(2013, 1, 2, 3, 4, 5),
@@ -713,6 +720,13 @@ class ArrowSpanRangeTests(Chai):
             (arrow.Arrow(2013, 1, 1, 3), arrow.Arrow(2013, 1, 1, 3, 59, 59, 999999)),
         ])
 
+        result = arrow.Arrow.span_range('hour', datetime(2013, 1, 1, 3, 30),
+            datetime(2013, 1, 1, 3, 30))
+
+        assertEqual(result, [
+            (arrow.Arrow(2013, 1, 1, 3), arrow.Arrow(2013, 1, 1, 3, 59, 59, 999999)),
+        ])
+
     def test_minute(self):
 
         result = arrow.Arrow.span_range('minute', datetime(2013, 1, 1, 0, 0, 30),
@@ -900,6 +914,9 @@ class ArrowHumanizeTests(Chai):
         assertEqual(self.now.humanize(later), 'seconds ago')
         assertEqual(later.humanize(self.now), 'in seconds')
 
+        assertEqual(self.now.humanize(later, only_distance=True), 'seconds')
+        assertEqual(later.humanize(self.now, only_distance=True), 'seconds')
+
     def test_minute(self):
 
         later = self.now.replace(minutes=1)
@@ -907,6 +924,10 @@ class ArrowHumanizeTests(Chai):
         assertEqual(self.now.humanize(later), 'a minute ago')
         assertEqual(later.humanize(self.now), 'in a minute')
 
+        assertEqual(self.now.humanize(later, only_distance=True), 'a minute')
+        assertEqual(later.humanize(self.now, only_distance=True), 'a minute')
+
+
     def test_minutes(self):
 
         later = self.now.replace(minutes=2)
@@ -914,6 +935,9 @@ class ArrowHumanizeTests(Chai):
         assertEqual(self.now.humanize(later), '2 minutes ago')
         assertEqual(later.humanize(self.now), 'in 2 minutes')
 
+        assertEqual(self.now.humanize(later, only_distance=True), '2 minutes')
+        assertEqual(later.humanize(self.now, only_distance=True), '2 minutes')
+
     def test_hour(self):
 
         later = self.now.replace(hours=1)
@@ -921,6 +945,9 @@ class ArrowHumanizeTests(Chai):
         assertEqual(self.now.humanize(later), 'an hour ago')
         assertEqual(later.humanize(self.now), 'in an hour')
 
+        assertEqual(self.now.humanize(later, only_distance=True), 'an hour')
+        assertEqual(later.humanize(self.now, only_distance=True), 'an hour')
+
     def test_hours(self):
 
         later = self.now.replace(hours=2)
@@ -928,6 +955,9 @@ class ArrowHumanizeTests(Chai):
         assertEqual(self.now.humanize(later), '2 hours ago')
         assertEqual(later.humanize(self.now), 'in 2 hours')
 
+        assertEqual(self.now.humanize(later, only_distance=True), '2 hours')
+        assertEqual(later.humanize(self.now, only_distance=True), '2 hours')
+
     def test_day(self):
 
         later = self.now.replace(days=1)
@@ -935,6 +965,9 @@ class ArrowHumanizeTests(Chai):
         assertEqual(self.now.humanize(later), 'a day ago')
         assertEqual(later.humanize(self.now), 'in a day')
 
+        assertEqual(self.now.humanize(later, only_distance=True), 'a day')
+        assertEqual(later.humanize(self.now, only_distance=True), 'a day')
+
     def test_days(self):
 
         later = self.now.replace(days=2)
@@ -942,6 +975,9 @@ class ArrowHumanizeTests(Chai):
         assertEqual(self.now.humanize(later), '2 days ago')
         assertEqual(later.humanize(self.now), 'in 2 days')
 
+        assertEqual(self.now.humanize(later, only_distance=True), '2 days')
+        assertEqual(later.humanize(self.now, only_distance=True), '2 days')
+
     def test_month(self):
 
         later = self.now.replace(months=1)
@@ -949,6 +985,9 @@ class ArrowHumanizeTests(Chai):
         assertEqual(self.now.humanize(later), 'a month ago')
         assertEqual(later.humanize(self.now), 'in a month')
 
+        assertEqual(self.now.humanize(later, only_distance=True), 'a month')
+        assertEqual(later.humanize(self.now, only_distance=True), 'a month')
+
     def test_months(self):
 
         later = self.now.replace(months=2)
@@ -956,6 +995,9 @@ class ArrowHumanizeTests(Chai):
         assertEqual(self.now.humanize(later), '2 months ago')
         assertEqual(later.humanize(self.now), 'in 2 months')
 
+        assertEqual(self.now.humanize(later, only_distance=True), '2 months')
+        assertEqual(later.humanize(self.now, only_distance=True), '2 months')
+
     def test_year(self):
 
         later = self.now.replace(years=1)
@@ -963,6 +1005,9 @@ class ArrowHumanizeTests(Chai):
         assertEqual(self.now.humanize(later), 'a year ago')
         assertEqual(later.humanize(self.now), 'in a year')
 
+        assertEqual(self.now.humanize(later, only_distance=True), 'a year')
+        assertEqual(later.humanize(self.now, only_distance=True), 'a year')
+
     def test_years(self):
 
         later = self.now.replace(years=2)
@@ -970,6 +1015,9 @@ class ArrowHumanizeTests(Chai):
         assertEqual(self.now.humanize(later), '2 years ago')
         assertEqual(later.humanize(self.now), 'in 2 years')
 
+        assertEqual(self.now.humanize(later, only_distance=True), '2 years')
+        assertEqual(later.humanize(self.now, only_distance=True), '2 years')
+
         arw = arrow.Arrow(2014, 7, 2)
 
         result = arw.humanize(self.datetime)
@@ -1087,4 +1135,3 @@ class ArrowUtilTests(Chai):
 
         with assertRaises(Exception):
             arrow.Arrow._get_iteration_params(None, None)
-
